.. rst-class:: hide-header

Flask-Coney
================

.. image:: _static/flask-coney-title.png
    :align: center

Flask-Coney is an extension for `Flask`_ that adds support for
`Pika`_ to your application. It aims to simplify using Pika with
Flask by providing useful defaults and decorators that make it
easier to accomplish common tasks. It is intended to use in a
multi-service system, where you want to have a distributed messaging
system.

.. _Pika: https://pika.readthedocs.io
.. _Flask: http://flask.pocoo.org/

User Guide
----------

.. toctree::
  :maxdepth: 2

  quickstart
  config
  patterns

API Reference
-------------

.. toctree::
   :maxdepth: 2

   api

Additional Information
----------------------

.. toctree::
   :maxdepth: 2

   license
   changelog
